@@ -6,7 +6,7 @@
  * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: debug.c 5898 2011-08-21 13:53:27Z rousseau $
+ * $Id: debug.c 6771 2013-10-17 13:02:41Z rousseau $
  */
 
 /**
@@ -15,12 +15,15 @@
  */
 
 #include "config.h"
+#include "misc.h"
 #include <stdarg.h>
 #include <stdlib.h>
 #include <unistd.h>
 #include <string.h>
 #include <stdio.h>
 
+/* We shall not export the log_msg() sumbol */
+#undef PCSC_API
 #include "debuglog.h"
 #include "strlcpycat.h"
 
@@ -56,16 +59,16 @@ static void log_init(void)
 	/* log to stderr and stderr is a tty? */
 	if (isatty(fileno(stderr)))
 	{
-		const char *terms[] = { "linux", "xterm", "xterm-color", "Eterm", "rxvt", "rxvt-unicode" };
 		char *term;
 
 		term = getenv("TERM");
 		if (term)
 		{
+			const char *terms[] = { "linux", "xterm", "xterm-color", "Eterm", "rxvt", "rxvt-unicode" };
 			unsigned int i;
 
 			/* for each known color terminal */
-			for (i = 0; i < sizeof(terms) / sizeof(terms[0]); i++)
+			for (i = 0; i < COUNT_OF(terms); i++)
 			{
 				/* we found a supported term? */
 				if (0 == strcmp(terms[i], term))
