@@ -6,7 +6,7 @@
  * Copyright (C) 2002-2009
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: hotplug.h 4544 2009-11-12 14:33:44Z rousseau $
+ * $Id: hotplug.h 5434 2010-12-08 14:13:21Z rousseau $
  */
 
 /**
@@ -17,11 +17,6 @@
 #ifndef __hotplug_h__
 #define __hotplug_h__
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #ifndef PCSCLITE_HP_DROPDIR
 #define PCSCLITE_HP_DROPDIR		"/usr/local/pcsc/drivers/"
 #endif
@@ -40,8 +35,4 @@ extern "C"
 	LONG HPStopHotPluggables(void);
 	void HPReCheckSerialReaders(void);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif
