@@ -10,7 +10,7 @@
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
  *
- * $Id: hotplug_libusb.c 5938 2011-09-03 21:43:53Z rousseau $
+ * $Id: hotplug_libusb.c 6750 2013-09-12 14:52:08Z rousseau $
  */
 
 /**
@@ -46,7 +46,6 @@
 #include "utils.h"
 
 #undef DEBUG_HOTPLUG
-#define ADD_SERIAL_NUMBER
 
 /* format is "%d:%d:%d", bus_number, device_address, interface */
 #define BUS_DEVICE_STRSIZE	10+1+10+1+10+1
@@ -58,6 +57,8 @@
 #define FALSE			0
 #define TRUE			1
 
+extern char Add_Serial_In_Name;
+
 /* we use the default libusb context */
 #define ctx NULL
 
@@ -544,12 +545,9 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 		sizeof(readerTracker[i].bus_device));
 	readerTracker[i].bus_device[sizeof(readerTracker[i].bus_device) - 1] = '\0';
 
-#ifdef ADD_SERIAL_NUMBER
-	if (desc.iSerialNumber)
+	if (Add_Serial_In_Name && desc.iSerialNumber)
 	{
 		libusb_device_handle *device;
-		unsigned char serialNumber[MAX_READERNAME];
-		char fullname[MAX_READERNAME];
 		int ret;
 
 		ret = libusb_open(dev, &device);
@@ -559,6 +557,8 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 		}
 		else
 		{
+			unsigned char serialNumber[MAX_READERNAME];
+
 			ret = libusb_get_string_descriptor_ascii(device, desc.iSerialNumber,
 				serialNumber, MAX_READERNAME);
 			libusb_close(device);
@@ -571,6 +571,8 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 			}
 			else
 			{
+				char fullname[MAX_READERNAME];
+
 				snprintf(fullname, sizeof(fullname), "%s (%s)",
 					driver->readerName, serialNumber);
 				readerTracker[i].fullName = strdup(fullname);
@@ -578,7 +580,6 @@ static LONG HPAddHotPluggable(struct libusb_device *dev,
 		}
 	}
 	else
-#endif
 		readerTracker[i].fullName = strdup(driver->readerName);
 
 	if (RFAddReader(readerTracker[i].fullName, PCSCLITE_HP_BASE_PORT + i,
