@@ -3,13 +3,13 @@
  *
  * Copyright (C) 2001-2003
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2002-2010
+ * Copyright (C) 2002-2011
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
  * The USB code was based partly on Johannes Erdfelt
  * libusb code found at libusb.sourceforge.net
  *
- * $Id: hotplug_linux.c 5351 2010-10-25 14:08:14Z rousseau $
+ * $Id: hotplug_linux.c 6759 2013-10-01 12:57:03Z rousseau $
  */
 
 /**
@@ -20,7 +20,7 @@
 #include "config.h"
 #include <string.h>
 
-#if defined(__linux__) && !defined(HAVE_LIBUSB) && !defined(HAVE_LIBHAL)
+#if defined(__linux__) && !defined(HAVE_LIBUSB) && !defined(HAVE_LIBUDEV)
 #include <sys/types.h>
 #include <stdio.h>
 #include <dirent.h>
@@ -183,9 +183,9 @@ static LONG HPReadBundleValues(void)
 #endif
 				listCount++;
 
-				if (listCount >= sizeof(bundleTracker)/sizeof(bundleTracker[0]))
+				if (listCount >= COUNT_OF(bundleTracker))
 				{
-					Log2(PCSC_LOG_CRITICAL, "Too many readers declared. Maximum is %d", sizeof(bundleTracker)/sizeof(bundleTracker[0]));
+					Log2(PCSC_LOG_CRITICAL, "Too many readers declared. Maximum is %zd", COUNT_OF(bundleTracker));
 					goto end;
 				}
 			}
@@ -258,7 +258,8 @@ static void HPEstablishUSBNotifications(void)
 					continue;
 				}
 
-				sprintf(dirpath, "%s/%s", PCSCLITE_USB_PATH, entry->d_name);
+				snprintf(dirpath, sizeof dirpath, "%s/%s",
+					PCSCLITE_USB_PATH, entry->d_name);
 
 				dirB = opendir(dirpath);
 
@@ -280,8 +281,9 @@ static void HPEstablishUSBNotifications(void)
 
 					/* Get the device number so we can distinguish
 					   multiple readers */
-					sprintf(filename, "%s/%s", dirpath, entryB->d_name);
-					sscanf(entryB->d_name, "%d", &deviceNumber);
+					snprintf(filename, sizeof filename, "%s/%s",
+						dirpath, entryB->d_name);
+					deviceNumber = atoi(entryB->d_name);
 
 					fd = open(filename, O_RDONLY);
 					if (fd < 0)
