@@ -3,10 +3,10 @@
  *
  * Copyright (C) 1999
  *  David Corcoran <corcoran@linuxnet.com>
- * Copyright (C) 2002-2009
+ * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: sys_generic.h 4836 2010-03-19 12:34:32Z rousseau $
+ * $Id: sys_generic.h 5434 2010-12-08 14:13:21Z rousseau $
  */
 
 /**
@@ -17,11 +17,6 @@
 #ifndef __sys_generic_h__
 #define __sys_generic_h__
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
-
 #include <sys/stat.h>
 #include <sys/mman.h>
 
@@ -35,8 +30,4 @@ extern "C"
 
 	int SYS_GetSeed(void);
 
-#ifdef __cplusplus
-}
-#endif
-
 #endif							/* __sys_generic_h__ */
