@@ -8,7 +8,7 @@
  * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_msg.c 5867 2011-07-09 11:50:16Z rousseau $
+ * $Id: winscard_msg.c 6441 2012-08-24 07:42:05Z rousseau $
  */
 
 /**
@@ -90,7 +90,6 @@ char *getSocketName(void)
 INTERNAL int ClientSetupSession(uint32_t *pdwClientID)
 {
 	struct sockaddr_un svc_addr;
-	int one;
 	int ret;
 	char *socketName;
 
@@ -116,8 +115,16 @@ INTERNAL int ClientSetupSession(uint32_t *pdwClientID)
 		return -1;
 	}
 
-	one = 1;
-	if (ioctl(*pdwClientID, FIONBIO, &one) < 0)
+	ret = fcntl(*pdwClientID, F_GETFL, 0);
+	if (ret < 0)
+	{
+		Log3(PCSC_LOG_CRITICAL, "Error: cannot retrieve socket %s flags: %s",
+			socketName, strerror(errno));
+		(void)close(*pdwClientID);
+		return -1;
+	}
+
+	if (fcntl(*pdwClientID, F_SETFL, ret | O_NONBLOCK) < 0)
 	{
 		Log3(PCSC_LOG_CRITICAL, "Error: cannot set socket %s nonblocking: %s",
 			socketName, strerror(errno));
