@@ -10,7 +10,7 @@
  * Copyright (C) 2009
  *  Jean-Luc Giraud <jlgiraud@googlemail.com>
  *
- * $Id: winscard_svc.c 5864 2011-07-09 11:37:48Z rousseau $
+ * $Id: winscard_svc.c 6709 2013-08-05 18:49:31Z rousseau $
  */
 
 /**
@@ -129,6 +129,8 @@ void ContextsDeinitialize(void)
 	listSize = list_size(&contextsList);
 	Log2(PCSC_LOG_DEBUG, "remaining threads: %d", listSize);
 	/* This is currently a no-op. It should terminate the threads properly. */
+
+	list_destroy(&contextsList);
 }
 
 /**
@@ -147,15 +149,15 @@ LONG CreateContextThread(uint32_t *pdwClientID)
 	int lrv;
 	int listSize;
 	SCONTEXT * newContext = NULL;
+	LONG retval = SCARD_E_NO_MEMORY;
 
 	(void)pthread_mutex_lock(&contextsList_lock);
-	listSize = list_size(&contextsList);
-	(void)pthread_mutex_unlock(&contextsList_lock);
 
+	listSize = list_size(&contextsList);
 	if (listSize >= contextMaxThreadCounter)
 	{
 		Log2(PCSC_LOG_CRITICAL, "Too many context running: %d", listSize);
-		goto error;
+		goto out;
 	}
 
 	/* Create the context for this thread. */
@@ -163,78 +165,80 @@ LONG CreateContextThread(uint32_t *pdwClientID)
 	if (NULL == newContext)
 	{
 		Log1(PCSC_LOG_CRITICAL, "Could not allocate new context");
-		goto error;
+		goto out;
 	}
 	memset(newContext, 0, sizeof(*newContext));
 
 	newContext->dwClientID = *pdwClientID;
 
 	/* Initialise the list of card contexts */
-	lrv = list_init(&(newContext->cardsList));
+	lrv = list_init(&newContext->cardsList);
 	if (lrv < 0)
 	{
 		Log2(PCSC_LOG_CRITICAL, "list_init failed with return value: %d", lrv);
-		goto error;
+		goto out;
 	}
 
 	/* request to store copies, and provide the metric function */
-	list_attributes_copy(&(newContext->cardsList), list_meter_int32_t, 1);
+	list_attributes_copy(&newContext->cardsList, list_meter_int32_t, 1);
 
 	/* Adding a comparator
 	 * The stored type is SCARDHANDLE (long) but has only 32 bits
 	 * usefull even on a 64-bit CPU since the API between pcscd and
 	 * libpcscliter uses "int32_t hCard;"
 	 */
-	lrv = list_attributes_comparator(&(newContext->cardsList),
+	lrv = list_attributes_comparator(&newContext->cardsList,
 		list_comparator_int32_t);
 	if (lrv != 0)
 	{
 		Log2(PCSC_LOG_CRITICAL,
 			"list_attributes_comparator failed with return value: %d", lrv);
-		list_destroy(&(newContext->cardsList));
-		goto error;
+		list_destroy(&newContext->cardsList);
+		goto out;
 	}
 
 	(void)pthread_mutex_init(&newContext->cardsList_lock, NULL);
 
-	(void)pthread_mutex_lock(&contextsList_lock);
 	lrv = list_append(&contextsList, newContext);
-	(void)pthread_mutex_unlock(&contextsList_lock);
 	if (lrv < 0)
 	{
 		Log2(PCSC_LOG_CRITICAL, "list_append failed with return value: %d",
 			lrv);
-		list_destroy(&(newContext->cardsList));
-		goto error;
+		list_destroy(&newContext->cardsList);
+		goto out;
 	}
 
-	rv = ThreadCreate(&(newContext->pthThread), THREAD_ATTR_DETACHED,
+	rv = ThreadCreate(&newContext->pthThread, THREAD_ATTR_DETACHED,
 		(PCSCLITE_THREAD_FUNCTION( )) ContextThread, (LPVOID) newContext);
 	if (rv)
 	{
 		int lrv2;
 
 		Log2(PCSC_LOG_CRITICAL, "ThreadCreate failed: %s", strerror(rv));
-		(void)pthread_mutex_lock(&contextsList_lock);
 		lrv2 = list_delete(&contextsList, newContext);
-		(void)pthread_mutex_unlock(&contextsList_lock);
 		if (lrv2 < 0)
 			Log2(PCSC_LOG_CRITICAL, "list_delete failed with error %d", lrv2);
-		list_destroy(&(newContext->cardsList));
-		goto error;
+		list_destroy(&newContext->cardsList);
+		goto out;
 	}
 
 	/* disable any suicide alarm */
 	if (AutoExit)
 		alarm(0);
 
-	return SCARD_S_SUCCESS;
+	retval = SCARD_S_SUCCESS;
 
-error:
-	if (newContext)
-		free(newContext);
-	(void)close(*pdwClientID);
-	return SCARD_E_NO_MEMORY;
+out:
+	(void)pthread_mutex_unlock(&contextsList_lock);
+
+	if (retval != SCARD_S_SUCCESS)
+	{
+		if (newContext)
+			free(newContext);
+		(void)close(*pdwClientID);
+	}
+
+	return retval;
 }
 
 /*
@@ -527,7 +531,7 @@ static void ContextThread(LPVOID newContext)
 				/* find the client */
 				(void)pthread_mutex_lock(&contextsList_lock);
 				psTargetContext = (SCONTEXT *) list_seek(&contextsList,
-					&(caStr.hContext));
+					&caStr.hContext);
 				(void)pthread_mutex_unlock(&contextsList_lock);
 				if (psTargetContext != NULL)
 				{
@@ -751,7 +755,7 @@ static LONG MSGRemoveContext(SCARDCONTEXT hContext, SCONTEXT * threadContext)
 		return SCARD_E_INVALID_VALUE;
 
 	(void)pthread_mutex_lock(&threadContext->cardsList_lock);
-	while (list_size(&(threadContext->cardsList)) != 0)
+	while (list_size(&threadContext->cardsList) != 0)
 	{
 		READER_CONTEXT * rContext = NULL;
 		SCARDHANDLE hCard, hLockId;
@@ -760,7 +764,7 @@ static LONG MSGRemoveContext(SCARDCONTEXT hContext, SCONTEXT * threadContext)
 		/*
 		 * Disconnect each of these just in case
 		 */
-		ptr = list_get_at(&(threadContext->cardsList), 0);
+		ptr = list_get_at(&threadContext->cardsList, 0);
 		if (NULL == ptr)
 		{
 			Log1(PCSC_LOG_CRITICAL, "list_get_at failed");
@@ -805,13 +809,15 @@ static LONG MSGRemoveContext(SCARDCONTEXT hContext, SCONTEXT * threadContext)
 			(void)SCardDisconnect(hCard, SCARD_RESET_CARD);
 
 		/* Remove entry from the list */
-		lrv = list_delete_at(&(threadContext->cardsList), 0);
+		lrv = list_delete_at(&threadContext->cardsList, 0);
 		if (lrv < 0)
 			Log2(PCSC_LOG_CRITICAL,
 				"list_delete_at failed with return value: %d", lrv);
+
+		UNREF_READER(rContext)
 	}
 	(void)pthread_mutex_unlock(&threadContext->cardsList_lock);
-	list_destroy(&(threadContext->cardsList));
+	list_destroy(&threadContext->cardsList);
 
 	/* We only mark the context as no longer in use.
 	 * The memory is freed in MSGCleanupCLient() */
@@ -823,36 +829,45 @@ static LONG MSGRemoveContext(SCARDCONTEXT hContext, SCONTEXT * threadContext)
 static LONG MSGAddHandle(SCARDCONTEXT hContext, SCARDHANDLE hCard,
 	SCONTEXT * threadContext)
 {
+	LONG retval = SCARD_E_INVALID_VALUE;
+
 	if (threadContext->hContext == hContext)
 	{
 		/*
 		 * Find an empty spot to put the hCard value
 		 */
-		int listLength, lrv;
+		int listLength;
 
-		listLength = list_size(&(threadContext->cardsList));
+		(void)pthread_mutex_lock(&threadContext->cardsList_lock);
+
+		listLength = list_size(&threadContext->cardsList);
 		if (listLength >= contextMaxCardHandles)
 		{
 			Log4(PCSC_LOG_DEBUG,
 				"Too many card handles for thread context @%p: %d (max is %d)"
 				"Restart pcscd with --max-card-handle-per-thread value",
 				threadContext, listLength, contextMaxCardHandles);
-			return SCARD_E_NO_MEMORY;
+			retval = SCARD_E_NO_MEMORY;
+		}
+		else
+		{
+			int lrv;
+
+			lrv = list_append(&threadContext->cardsList, &hCard);
+			if (lrv < 0)
+			{
+				Log2(PCSC_LOG_CRITICAL,
+					"list_append failed with return value: %d", lrv);
+				retval = SCARD_E_NO_MEMORY;
+			}
+			else
+				retval = SCARD_S_SUCCESS;
 		}
 
-		(void)pthread_mutex_lock(&threadContext->cardsList_lock);
-		lrv = list_append(&(threadContext->cardsList), &hCard);
 		(void)pthread_mutex_unlock(&threadContext->cardsList_lock);
-		if (lrv < 0)
-		{
-			Log2(PCSC_LOG_CRITICAL, "list_append failed with return value: %d",
-				lrv);
-			return SCARD_E_NO_MEMORY;
-		}
-		return SCARD_S_SUCCESS;
 	}
 
-	return SCARD_E_INVALID_VALUE;
+	return retval;
 }
 
 static LONG MSGRemoveHandle(SCARDHANDLE hCard, SCONTEXT * threadContext)
@@ -860,7 +875,7 @@ static LONG MSGRemoveHandle(SCARDHANDLE hCard, SCONTEXT * threadContext)
 	int lrv;
 
 	(void)pthread_mutex_lock(&threadContext->cardsList_lock);
-	lrv = list_delete(&(threadContext->cardsList), &hCard);
+	lrv = list_delete(&threadContext->cardsList, &hCard);
 	(void)pthread_mutex_unlock(&threadContext->cardsList_lock);
 	if (lrv < 0)
 	{
@@ -886,7 +901,7 @@ static LONG MSGCheckHandleAssociation(SCARDHANDLE hCard,
 	}
 
 	(void)pthread_mutex_lock(&threadContext->cardsList_lock);
-	list_index = list_locate(&(threadContext->cardsList), &hCard);
+	list_index = list_locate(&threadContext->cardsList, &hCard);
 	(void)pthread_mutex_unlock(&threadContext->cardsList_lock);
 	if (list_index >= 0)
 		return 0;
