@@ -5,10 +5,10 @@
  *  David Corcoran <corcoran@linuxnet.com>
  * Copyright (C) 2003-2004
  *  Damien Sauveron <damien.sauveron@labri.fr>
- * Copyright (C) 2002-2009
+ * Copyright (C) 2002-2010
  *  Ludovic Rousseau <ludovic.rousseau@free.fr>
  *
- * $Id: winscard_svc.h 4722 2010-02-09 09:09:13Z rousseau $
+ * $Id: winscard_svc.h 5434 2010-12-08 14:13:21Z rousseau $
  */
 
 /**
@@ -20,16 +20,9 @@
 #ifndef __winscard_svc_h__
 #define __winscard_svc_h__
 
-#ifdef __cplusplus
-extern "C"
-{
-#endif
 	LONG ContextsInitialize(int, int);
 	void ContextsDeinitialize(void);
 	LONG CreateContextThread(uint32_t *);
 	LONG MSGSignalClient(uint32_t filedes, LONG rv);
-#ifdef __cplusplus
-}
-#endif
 
 #endif
